==> gnuradio_3.6.4.1.orig.tar.gz: gnuradio-3.6.4.1/gr-analog/lib/rail_ff_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2004,2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_ANALOG_RAIL_FF_IMPL_H
#define INCLUDED_ANALOG_RAIL_FF_IMPL_H

#include <analog/rail_ff.h>

namespace gr {
  namespace analog {
    
    class rail_ff_impl : public rail_ff
    {
    private:
      float d_lo, d_hi;
      float d_mid, d_clip;

      void set_clipping();

    public:
      rail_ff_impl(float lo, float hi);
      ~rail_ff_impl();

      float lo() const { return d_lo; }
      float hi() const { return d_hi; }

      void set_lo(float lo);
      void set_hi(float hi);

      int work(int noutput_items,
	       gr_vector_const_void_star &input_items,
	       gr_vector_void_star &output_items);
    };

  } /* namespace analog */
} /* namespace gr */

#endif /* INCLUDED_ANALOG_RAIL_FF_IMPL_H */

==> gnuradio_3.7.2.1.orig.tar.gz: gnuradio-3.7.2.1/gr-analog/lib/rail_ff_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2004,2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_ANALOG_RAIL_FF_IMPL_H
#define INCLUDED_ANALOG_RAIL_FF_IMPL_H

#include <gnuradio/analog/rail_ff.h>

namespace gr {
  namespace analog {
    
    class rail_ff_impl : public rail_ff
    {
    private:
      float d_lo, d_hi;
      float d_mid, d_clip;

      void set_clipping();

    public:
      rail_ff_impl(float lo, float hi);
      ~rail_ff_impl();

      float lo() const { return d_lo; }
      float hi() const { return d_hi; }

      void set_lo(float lo);
      void set_hi(float hi);

      int work(int noutput_items,
	       gr_vector_const_void_star &input_items,
	       gr_vector_void_star &output_items);
    };

  } /* namespace analog */
} /* namespace gr */

#endif /* INCLUDED_ANALOG_RAIL_FF_IMPL_H */
